pub fn decode_portable_json<T: DeserializeOwned>(wire: &str) -> Result<T, Error>Expand description
Decodes a typed value after enforcing the portable JSON number profile.
pub fn decode_portable_json<T: DeserializeOwned>(wire: &str) -> Result<T, Error>Decodes a typed value after enforcing the portable JSON number profile.